
# Titulo de la Sintaxis: 
# Datos de la vivienda y el hogar 

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular estadisticos para variables dicotomicas 
srvyr_prop <- function(design, x) {
  
  design %>% 
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace", 
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base Hogar 
df_f1_hogar <- import("/BDD_ENDI_R1_f1_hogar_gal.rds")
df_f1_hogar <- as_tibble(df_f1_hogar)
df_f1_hogar 

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   
dicc_f1_hog <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f1_hogar") 
dicc_f1_hog <- as_tibble(dicc_f1_hog) 
dicc_f1_hog 

#==============================================================================#
####                          Calculo de indicadores                        ####
#==============================================================================#

# Hogares que utilizan suministros seguros de agua para beber -----------------# 

# Componentes del indicador:
# 1. Tipo de suministro
# 2. Calidad del agua
# 3. Cercania del suministro
# 4. Suficiencia de agua para beber 

# 1. Tipo de suministro 
# Revision
df_f1_hogar %>% 
  freq(f1_s3_10, cumul = F, report.nas = F)

df_f1_hogar %>% 
  freq(f1_s7_1, cumul = F, report.nas = F)

df_f1_hogar <- df_f1_hogar %>%
  mutate(f1_s3_10r = case_when(
    (f1_s3_10 == 1 | f1_s3_10 == 2) ~ 1,
    (f1_s3_10 >= 3 & f1_s3_10 <= 5) ~ 2, 
    TRUE ~ NA_real_ 
  ))

df_f1_hogar %>%
  freq(f1_s3_10r, cumul = F, report.nas = F)

# Componente 1 
df_f1_hogar <- df_f1_hogar %>%
  mutate(agua_cp1 = case_when(
    f1_s7_1 == 1 | f1_s7_1 == 2 | f1_s7_1 == 3 | f1_s7_1 == 7 | f1_s7_1 == 9 | 
      ((f1_s7_1 == 5 | f1_s7_1 == 6) & f1_s3_10r == 1)  ~ 1, # Tipo A
    f1_s7_1 == 4 | f1_s7_1 == 8 | f1_s7_1 == 10 | f1_s7_1 == 11 |
      ((f1_s7_1 == 5 | f1_s7_1 == 6) & f1_s3_10r == 2) ~ 2, # Tipo B 
    f1_s7_1 == 12 | f1_s7_1 == 13  ~ 3, # Tipo C 
    TRUE ~ NA_real_ 
  ))

df_f1_hogar %>%
  freq(agua_cp1, cumul = F, report.nas = F)

# 2. Calidad del agua - tratamiento 
# 2.1. Si la beben tal como llega al hogar, no tiene agua segura.
# 2.2. Si la hierven o tiene algun otro tratamiento, tiene calidad.
# 2.3. La respuesta "no sabe" no sera tomada en cuenta 

# Revision 
df_f1_hogar %>% 
  freq(f1_s7_23, cumul = F, report.nas = F)

# Componente 2
df_f1_hogar <- df_f1_hogar %>%
  mutate(agua_cp2 = case_when(
    f1_s7_23 >= 2 & f1_s7_23 <= 5 ~ 1,
    f1_s7_23 == 1 ~ 2, 
    TRUE ~ NA_real_ 
  ))

df_f1_hogar %>%
  freq(agua_cp2, cumul = F, report.nas = F) 

# 3. Cercania del suministro 
# Revision
df_f1_hogar %>% 
  freq(f1_s7_1, cumul = F, report.nas = F)

df_f1_hogar %>% 
  freq(f1_s7_2, cumul = F, report.nas = F)

df_f1_hogar %>% 
  descr(f1_s7_3,
        stats = "common")

# Componente 3
df_f1_hogar <- df_f1_hogar %>%
  mutate(agua_cp3 = case_when(
    (f1_s7_2 == 1 | f1_s7_2 == 2) | (f1_s7_1 == 5 | f1_s7_1 == 6) ~ 1,
    f1_s7_2 == 3 & (f1_s7_3 <= 30 & !is.na(f1_s7_3)) ~ 2,
    f1_s7_2 == 3 & (f1_s7_3 > 30 & f1_s7_3 < 888) ~ 3,
    TRUE ~ NA_real_ 
  )) # Carro reartidor, no se contempla en este calculo 

df_f1_hogar %>%
  freq(agua_cp3, cumul = F, report.nas = F)

# 4. Suficiencia de agua para beber 
# Revision 
df_f1_hogar %>% 
  freq(f1_s7_4, cumul = F, report.nas = F)

# Componente 4
df_f1_hogar <- df_f1_hogar %>%
  mutate(agua_cp4 = case_when(
    f1_s7_4 == 1 ~ 1,
    f1_s7_4 == 2 ~ 2,
    TRUE ~ NA_real_ 
  ))# no se contempla el "no sabe"

df_f1_hogar %>%
  freq(agua_cp4, cumul = F, report.nas = F)

# Servicios de agua para beber manejado de forma segura 
df_f1_hogar <- df_f1_hogar %>%
  mutate(i_agua = case_when(
    agua_cp1 == 1 & agua_cp2 == 1 & agua_cp3 == 1 & agua_cp4 == 1 ~ 1,
    (agua_cp1 == 1 & agua_cp2 == 1 & agua_cp3 == 1 & agua_cp4 == 2) | 
      (agua_cp1 == 1 & agua_cp2 == 1 & agua_cp3 == 2) ~ 2,
    (agua_cp1 == 1 & agua_cp2 == 2 & agua_cp3 == 1) | 
      (agua_cp1 == 1 & agua_cp2 == 2 & agua_cp3 == 2) ~ 3,
    agua_cp1 == 1 & agua_cp3 == 3 ~ 4,
    agua_cp1 == 2 ~ 5,
    agua_cp1 == 3 ~ 6,
    TRUE ~ NA_real_ 
  ))

df_f1_hogar = apply_labels(df_f1_hogar,
                           i_agua = num_lab(
                             "1 Seguro
                              2 Básico 1
                              3 Básico 2
                              4 Limitado
                              5 No mejorado
                              6 Superficial"
                           ))

df_f1_hogar %>%
  freq(i_agua, cumul = F, report.nas = F)

# Indicador 
df_f1_hogar <- df_f1_hogar %>%
  mutate(agua_segura = case_when(
    i_agua == 1  ~ 1,
    !is.na(i_agua) ~ 0,
    TRUE ~ NA_real_ 
  ))

df_f1_hogar %>%
  freq(agua_segura, cumul = F, report.nas = F)

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f1_hogar %>% as_survey_design(ids = c("id_upm", "id_viv"),
                                                  fpc = c("ppe", "pse"),
                                                  weights = "fexp")

options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Hogares que utilizan suministros seguros de agua para beber 
survey_design %>%
  srvyr_prop(agua_segura)
