
# Titulo de la Sintaxis: 
# Datos de la vivienda y el hogar 

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular estadisticos para variables dicotomicas 
srvyr_prop <- function(design, x) {
  
  design %>% 
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace", 
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base Personas  
df_f1_personas <- import("/BDD_ENDI_R1_f1_personas_gal.rds")
df_f1_personas <- as_tibble(df_f1_personas)
df_f1_personas 

# Base Hogar 
df_f1_hogar <- import("/BDD_ENDI_R1_f1_hogar_gal.rds") 
df_f1_hogar <- as_tibble(df_f1_hogar) 
df_f1_hogar 

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   

# Personas
dicc_f1_per <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f1_personas")
dicc_f1_per <- as_tibble(dicc_f1_per)
dicc_f1_per

# Hogares 
dicc_f1_hog <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f1_hogar") 
dicc_f1_hog <- as_tibble(dicc_f1_hog) 
dicc_f1_hog 

#------------------------------------------------------------------------------#
# Join
#------------------------------------------------------------------------------#

# Variables compartidas
df_f1_hogar <- df_f1_hogar %>% 
  select(-c(id_upm, id_viv, fecha_anio, fecha_mes, 
            fecha_dia, fexp, ppe, pse))

# Join
df_f1_perhog <- df_f1_personas %>%  
  inner_join(df_f1_hogar, by = c("id_hogar"))

rm(df_f1_personas, df_f1_hogar)

#==============================================================================#
####                          Calculo de indicadores                        ####
#==============================================================================#

# Hacinamiento ----------------------------------------------------------------#

# Revision 
df_f1_perhog %>% 
  descr(f1_s3_16,
        stats = c("common"))

df_f1_perhog <- df_f1_perhog %>%
  mutate(f1_s3_16_dor = case_when(
    f1_s3_16 == 0 ~ 1, 
    TRUE ~ f1_s3_16
  ))

# Conteo de personas por hogar 
df_f1_perhog <- df_f1_perhog %>%
  mutate(pers = 1)

df_f1_perhog <- df_f1_perhog %>%
  group_by(id_hogar) %>% 
  mutate(numpers = sum(pers)) %>% 
  ungroup()

df_f1_perhog %>% 
  descr(numpers,
        stats = c("common"))

# Relacion entre numero de personas y dormitorios
df_f1_perhog <- df_f1_perhog %>%
  mutate(percuart = numpers / f1_s3_16_dor)

# Indicador 
df_f1_perhog <- df_f1_perhog %>%
  mutate(hacm = case_when(
    !is.na(percuart) & percuart > 3 ~ 1, 
    !is.na(percuart) & percuart <= 3 ~ 0,
    TRUE ~ NA_real_
  ))

df_f1_perhog %>%
  freq(hacm, cumul = F, report.nas = F)

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f1_perhog %>% as_survey_design(ids = c("id_upm", "id_viv"),
                                                   fpc = c("ppe", "pse"),
                                                   weights = "fexp")

options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Hacinamiento
survey_design %>% 
  srvyr_prop(hacm)

