
# Titulo de la Sintaxis: 
# Estado nutricional a partir de indicadores antropometricos

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular estadisticos para variables dicotomicas 
srvyr_prop <- function(design, x) {
  
  design %>% 
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace", 
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base Personas  
df_f1_personas <- import("/BDD_ENDI_R1_f1_personas_gal.rds")
df_f1_personas <- as_tibble(df_f1_personas)
df_f1_personas 

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   
dicc_f1_per <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f1_personas")
dicc_f1_per <- as_tibble(dicc_f1_per)
dicc_f1_per

#==============================================================================#
####    Calculo de variables antropometricas necesarias para el indicador   ####
#==============================================================================#

# Estimacion de la edad en dias -----------------------------------------------#

df_f1_personas <- df_f1_personas %>% 
  mutate(dob = paste(f1_s5_2_3, f1_s5_2_2, f1_s5_2_1)) %>% 
  mutate(dov = paste(f1_s5_3_3, f1_s5_3_2, f1_s5_3_1)) %>%  
  mutate(dob = as_date(dob)) %>%   
  mutate(dov = as_date(dov)) %>%  
  mutate(edaddias = (dob %--% dov) / days(1)) 

df_f1_personas %>%
  descr(edaddias, 
        stats = c("common"),
        round.digits = 2) 

# Estimacion del peso (kg) ----------------------------------------------------#

# Validacion de las 3 medidas del peso
df_f1_personas <- df_f1_personas %>%
  mutate(aux_peso = abs(f1_s5_4_1 - f1_s5_4_2)) 

df_f1_personas <- df_f1_personas %>%
  mutate(f1_s5_4_3 = case_when(
    aux_peso <= 0.5 & !is.na(f1_s5_4_3) ~ NA_real_,
    TRUE ~ f1_s5_4_3 
  )) 

# Se calcula el peso en kg
# Distancia entre las tres medidas 
df_f1_personas <- df_f1_personas %>%
  mutate(d1 = abs(f1_s5_4_1 - f1_s5_4_2)) %>%
  mutate(d2 = abs(f1_s5_4_1 - f1_s5_4_3)) %>%
  mutate(d3 = abs(f1_s5_4_2 - f1_s5_4_3))

# Variable identificador 
# Distancia entre toma 1 y toma 2 es menor o igual a 0.5
df_f1_personas <- df_f1_personas %>%
  mutate(s = case_when(
    d1 <= 0.5 ~ 1,
    d1 > 0.5 ~ 0,
    TRUE ~ NA_real_
  )) 

# Promedio simple entre toma 1 y toma 2
df_f1_personas <- df_f1_personas %>% 
  mutate(peso = case_when(
    s == 1 ~ (f1_s5_4_1 + f1_s5_4_2) / 2,
    TRUE ~ NA_real_
  ))

df_f1_personas %>%
  descr(peso, 
        stats = c("common"),
        round.digits = 2) 

# Caso contrario, promedio de la menor distancia entre las 3 mediciones 
# Distancia minima
df_f1_personas <- df_f1_personas %>% 
  mutate(dmin = case_when(
    (d1 <= d2 & d1 <= d3) |
      (!is.na(d1) & is.na(d2) & is.na(d3)) ~ d1,
    (d2 <= d1 & d2 <= d3) |
      (!is.na(d2) & is.na(d1) & is.na(d3)) ~ d2,
    (d3 <= d1 & d3 <= d2) |
      (!is.na(d3) & is.na(d1) & is.na(d2)) ~ d3, 
    TRUE ~ NA_real_
  ))

df_f1_personas <- df_f1_personas %>%
  mutate(peso = case_when(
    d3 == dmin ~ (f1_s5_4_2 + f1_s5_4_3) / 2, 
    d2 == dmin ~ (f1_s5_4_1 + f1_s5_4_3) / 2, 
    d1 == dmin ~ (f1_s5_4_1 + f1_s5_4_2) / 2,
    TRUE ~ peso
  )) 

df_f1_personas %>%
  descr(peso, 
        stats = c("common"),
        round.digits = 2) 

# Estimacion de la talla (cm) -------------------------------------------------#

# Validacion de las 3 medidas de la longitud
df_f1_personas <- df_f1_personas %>%
  mutate(aux_long = abs(f1_s5_5_1 - f1_s5_5_2))

df_f1_personas <- df_f1_personas %>%
  mutate(f1_s5_5_3 = case_when(
    aux_long <= 0.5 & !is.na(f1_s5_5_3) ~ NA_real_,
    TRUE ~ f1_s5_5_3
  ))

# Validacion de las 3 medidas de la talla
df_f1_personas <- df_f1_personas %>%
  mutate(aux_tal = abs(f1_s5_6_1 - f1_s5_6_2))

df_f1_personas <- df_f1_personas %>%
  mutate(f1_s5_6_3 = case_when(
    aux_tal <= 0.5 & !is.na(f1_s5_6_3) ~ NA_real_,
    TRUE ~ f1_s5_6_3
  ))

# Se calcula la talla en cm.
# Consolido las tomas para longitud y talla

# Talla 1 
df_f1_personas <- df_f1_personas %>% 
  mutate(talla1 = case_when(
    is.na(f1_s5_5_1) & !is.na(f1_s5_6_1) ~ f1_s5_6_1,
    !is.na(f1_s5_5_1) & is.na(f1_s5_6_1) ~ f1_s5_5_1, 
    TRUE ~ NA_real_
  ))

# Talla 2
df_f1_personas <- df_f1_personas %>% 
  mutate(talla2 = case_when(
    is.na(f1_s5_5_2) & !is.na(f1_s5_6_2) ~ f1_s5_6_2,
    !is.na(f1_s5_5_2) & is.na(f1_s5_6_2) ~ f1_s5_5_2, 
    TRUE ~ NA_real_
  ))

# Talla 3 
df_f1_personas <- df_f1_personas %>% 
  mutate(talla3 = case_when(
    is.na(f1_s5_5_3) & !is.na(f1_s5_6_3) ~ f1_s5_6_3,
    !is.na(f1_s5_5_3) & is.na(f1_s5_6_3) ~ f1_s5_5_3, 
    TRUE ~ NA_real_
  ))

# Distancia entre las tres medidas
df_f1_personas <- df_f1_personas %>%
  mutate(d1_tal = abs(talla1 - talla2)) %>%
  mutate(d2_tal = abs(talla1 - talla3)) %>%
  mutate(d3_tal = abs(talla2 - talla3))

# Variable identificador 
# Distancia entre toma 1 y toma 2 es menor o igual a 0.5
df_f1_personas <- df_f1_personas %>%
  mutate(s_tal = case_when(
    d1_tal <= 0.5 ~ 1, 
    d1_tal > 0.5 ~ 0, 
    TRUE ~ NA_real_
  ))

# Promedio simple entre toma 1 y toma 2
df_f1_personas <- df_f1_personas %>% 
  mutate(talla = case_when(
    s_tal == 1 ~ (talla1 + talla2) / 2, 
    TRUE ~ NA_real_
  ))

df_f1_personas %>%
  descr(talla, 
        stats = c("common"),
        round.digits = 2)

# Caso contrario, promedio de la menor distancia entre las 3 mediciones
# Distancia minima
df_f1_personas <- df_f1_personas %>% 
  mutate(dmin_tal = case_when(
    (d1_tal <= d2_tal & d1_tal <= d3_tal) |
      (!is.na(d1_tal) & is.na(d2_tal) & is.na(d3_tal)) ~ d1_tal,
    (d2_tal <= d1_tal & d2_tal <= d3_tal) |
      (!is.na(d2_tal) & is.na(d1_tal) & is.na(d3_tal)) ~ d2_tal,
    (d3_tal <= d1_tal & d3_tal <= d2_tal) |
      (!is.na(d3_tal) & is.na(d1_tal) & is.na(d2_tal)) ~ d3_tal, 
    TRUE ~ NA_real_
  ))

df_f1_personas <- df_f1_personas %>%
  mutate(talla = case_when(
    d3_tal == dmin_tal ~ (talla2 + talla3) / 2, 
    d2_tal == dmin_tal ~ (talla1 + talla3) / 2,
    d1_tal == dmin_tal ~ (talla1 + talla2) / 2,
    TRUE ~ talla
  )) 

df_f1_personas %>%
  descr(talla, 
        stats = c("common"),
        round.digits = 2)

# Sexo ------------------------------------------------------------------------#

df_f1_personas <- df_f1_personas %>%
  mutate(sexo = unlabel(f1_s1_2))

df_f1_personas %>%
  freq(sexo, cumul = F, report.nas = F)

#==============================================================================#
####           Calculo de puntuaciones z de antropometria infantil          ####
#==============================================================================#

# Valoracion de los z-scores 
df_f1_personas <- df_f1_personas %>% 
  mutate(anthro_zscores(
    sex = sexo,
    age = edaddias,
    weight = peso,
    lenhei = talla
  ))

#==============================================================================#
####     Construccion de las variables de desnutricion con los z-score      ####
#==============================================================================#

# Definicion de la edad en dias de la poblacion menor a 2 anios:
# Dias = 365.25 * 2 = 730.5 ----> 731 (valor aproximado) (Manual Anthro OMS)

# Desnutricion cronica para menores de 2 anios de edad ------------------------#

# Revision 
df_f1_personas %>%
  descr(zlen, 
        stats = c("common"))

# Indicador 
df_f1_personas <- df_f1_personas %>%
  mutate(dcronica_2 = case_when(
    (zlen >= -6 & zlen < -2) & (edaddias < 731 & !is.na(edaddias)) ~ 1,
    (zlen >= -2 & zlen <= 6) & (edaddias < 731 & !is.na(edaddias)) ~ 0, 
    TRUE ~ NA_real_ 
  ))

df_f1_personas %>%
  freq(dcronica_2, cumul = F, report.nas = F)

# Definicion de la edad en dias de la poblacion menor a 5 anios:
# Dias = 365.25 * 5 = 1826.25 ----> 1826 (valor aproximado) (Manual Anthro OMS)

# Desnutricion cronica para menores de 5 anios de edad ------------------------#

# Indicador 
df_f1_personas <- df_f1_personas %>%
  mutate(dcronica = case_when(
    (zlen >= -6 & zlen < -2) & (edaddias < 1826 & !is.na(edaddias)) ~ 1,
    (zlen >= -2 & zlen <= 6) & (edaddias < 1826 & !is.na(edaddias)) ~ 0, 
    TRUE ~ NA_real_))

df_f1_personas %>%
  freq(dcronica, cumul = F, report.nas = F)

# Desnutricion cronica en ninas/os de 2 a 5 anios -----------------------------#

# Indicador 
df_f1_personas <-  df_f1_personas %>%
  mutate(dcronica2_5 = case_when(
    (zlen >= -6 & zlen < -2) & (edaddias >= 731 & edaddias < 1826) ~ 1,
    (zlen >= -2 & zlen <= 6) & (edaddias >= 731 & edaddias < 1826) ~ 0, 
    TRUE ~ NA_real_
  ))

df_f1_personas %>%
  freq(dcronica2_5, cumul = F, report.nas = F)

# Sobrepeso para menores de 5 anios de edad -----------------------------------#

# Revision
df_f1_personas %>%
  descr(zbmi, 
        stats = c("common"))

# Indicador
df_f1_personas <- df_f1_personas %>%
  mutate(sp5 = case_when(
    (zbmi > 2 & zbmi <= 3) & (edaddias < 1826 & !is.na(edaddias)) ~ 1,
    ((zbmi >= -5 & zbmi <= 2) | (zbmi > 3 & zbmi <= 5)) & 
      (edaddias < 1826 & !is.na(edaddias)) ~ 0, 
    TRUE ~ NA_real_ 
  ))

df_f1_personas %>%
  freq(sp5, cumul = F, report.nas = F)

# Sobrepeso y obesidad para menores de 5 anios de edad ------------------------#

# Indicador
df_f1_personas <- df_f1_personas %>%
  mutate(spob5 = case_when(
    (zbmi > 2 & zbmi <= 5) & (edaddias < 1826 & !is.na(edaddias)) ~ 1,
    (zbmi >= -5 & zbmi <= 2) & (edaddias < 1826 & !is.na(edaddias)) ~ 0, 
    TRUE ~ NA_real_ 
  ))

df_f1_personas %>%
  freq(spob5, cumul = F, report.nas = F)

# Malnutricion en para menores de 5 anios -------------------------------------#

# Indicador 
df_f1_personas <-  df_f1_personas %>%
  mutate(malnutricion = case_when(
    (zwfl >= -5 & zwfl < -2) & (edaddias < 1826 & !is.na(edaddias)) ~ 1, # Desnutricion Aguda
    (zwfl >= -2 & zwfl <= 2) & (edaddias < 1826 & !is.na(edaddias)) ~ 0, 
    (zwfl > 2 & zwfl <= 3) & (edaddias < 1826 & !is.na(edaddias)) ~ 1, # Sobrepeso
    (zwfl > 3 & zwfl <= 5) & (edaddias < 1826 & !is.na(edaddias)) ~ 1, # Obesidad
    TRUE ~ NA_real_
  ))

df_f1_personas %>%
  freq(malnutricion, cumul = F, report.nas = F)

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f1_personas %>% as_survey_design(ids = c("id_upm", "id_viv"),
                                                     fpc = c("ppe", "pse"),
                                                     weights = "fexp")

options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Desnutricion cronica para menores de 2 anios de edad 
survey_design %>%
  srvyr_prop(dcronica_2)

# Desnutricion cronica para menores de 5 anios de edad 
survey_design %>%
  srvyr_prop(dcronica)

# Desnutricion cronica en ninas/os de 2 a 5 anios
survey_design %>%
  srvyr_prop(dcronica2_5)

# Sobrepeso para menores de 5 anios de edad 
survey_design %>%
  srvyr_prop(sp5)

# Sobrepeso y obesidad para menores de 5 anios de edad 
survey_design %>%
  srvyr_prop(spob5)

# Malnutricion en para menores de 5 anios
survey_design %>%
  srvyr_prop(malnutricion)
