
# Titulo de la Sintaxis: 
# Vacunacion 

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular estadisticos para variables dicotomicas 
srvyr_prop <- function(design, x) {
  
  design %>% 
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace",
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base MEF 
df_f2_mef <- import("/BDD_ENDI_R1_f2_mef_gal.rds")
df_f2_mef <- as_tibble(df_f2_mef) 
df_f2_mef

# Base Salud en la Ninez 
df_f2_salud_ninez <- import("/BDD_ENDI_R1_f2_salud_ninez_gal.rds")
df_f2_salud_ninez <- as_tibble(df_f2_salud_ninez) 
df_f2_salud_ninez

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   
# MEF
dicc_f2_mef <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f2_mef")
dicc_f2_mef <- as_tibble(dicc_f2_mef)   
dicc_f2_mef

# Salud en la Ninez 
dicc_f2_sani <- import("/Diccionario_ENDI_gal.xlsx",
                       which = "f2_salud_ninez")
dicc_f2_sani <- as_tibble(dicc_f2_sani)   
dicc_f2_sani

#==============================================================================#
####           Calculo de variables necesarias para el indicador            ####
#==============================================================================#

#------------------------------------------------------------------------------#
# Se procede a cambiar la base de mef de ancho a largo en funcion del numero 
# de hijos
#------------------------------------------------------------------------------#

# Nueva base con las variables de los hijos de las mefs
df_f2_hijos <- df_f2_mef %>% 
  select(starts_with("id"), starts_with("f2_s2_235_cod_"), 
         starts_with("f2_s2_235_a_"), starts_with("f2_s2_235_b_dia_"), 
         starts_with("f2_s2_235_b_mes_"), starts_with("f2_s2_235_b_anio_")) 

# Cambio de la base de ancho a largo 
df_f2_hijos_long <- df_f2_hijos %>% 
  pivot_longer(
    cols = starts_with("f2_s2_235_"),
    names_to = c(".value", "ord_hijo"),
    names_pattern = "([A-Za-z]+)_([0-9]+)"
  )

df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(across(c(cod, dia, mes, anio), as.character))

df_f2_hijos_long <- df_f2_hijos_long %>% 
  rename(sexo = a)

rm(df_f2_hijos, df_f2_mef)

# Creacion de variables con dos digitos  
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(cod = case_when(
    nchar(cod) == 1 ~ paste0("0", cod),
    TRUE ~ cod
  )) %>% 
  mutate(ord_hijo = case_when(
    nchar(ord_hijo) == 1 ~ paste0("0", ord_hijo),
    TRUE ~ ord_hijo
  ))

# Creacion de identificadores 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(id_hijo_ord = case_when(
    !is.na(cod) ~ paste0(id_mef, cod, ord_hijo),
    TRUE ~ NA_character_
  ))

# Mantengo la base de los hijos registrados 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  filter(!is.na(id_hijo_ord))

# Mantengo variables a utilizar 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  select(id_hijo_ord, dia, mes, anio, sexo)

#------------------------------------------------------------------------------#
# Se procede a cambiar la base de hijos de la seccion 4 de ancho a largo en 
# funcion de las vacunas  
#------------------------------------------------------------------------------#

# Cambio de la base de ancho a largo 
df_f2_hijos_vac_long <- df_f2_salud_ninez %>% 
  pivot_longer(
    cols = starts_with(c("f2_s4j_501_")),
    names_to = c(".value", ".value", "ord_vac", ".value"),
    names_pattern = "([a-z])([a-z_])([a-z])(.*)"   
  ) 

rm(df_f2_salud_ninez)

# Cambio de nombres 
df_f2_hijos_vac_long <- df_f2_hijos_vac_long %>%
  rename(
    vacuna = a_,
    dia_vac = a__dia, 
    mes_vac = a__mes,
    anio_vac = a__anio,
    madre = b_ 
  )

#------------------------------------------------------------------------------#
# Join -  Base de vacunas por hijos y base de hijos
#------------------------------------------------------------------------------#

# Join 
df_f2_hijos_long_long <- df_f2_hijos_vac_long %>% 
  left_join(df_f2_hijos_long, by = c("id_hijo_ord")) 
# Se utiliza left join para mantener la estructura de la base 
# df_f2_hijos_vac_long

rm(df_f2_hijos_long, df_f2_hijos_vac_long)

# Estimacion de la edad de vacunación en dias 
df_f2_hijos_long_long <- df_f2_hijos_long_long %>%
  mutate(across(ends_with("_vac"), as.character)) %>% 
  mutate(dob = paste(anio, mes, dia)) %>%
  mutate(dov = paste(anio_vac, mes_vac, dia_vac)) %>%
  mutate(dob = as_date(dob)) %>%   
  mutate(dov = as_date(dov)) %>%  
  mutate(edaddias = (dob %--% dov) / days(1)) 

df_f2_hijos_long_long %>%
  descr(edaddias, 
        stats = c("common"),
        round.digits = 2) 

#------------------------------------------------------------------------------#
# Se procede a cambiar la base de vacunacion de los hijos de largo a ancho 
# en funcion de los hijos 
#------------------------------------------------------------------------------#

# Cambio de la base de largo a ancho
df_f2_hijos_wide <- df_f2_hijos_long_long %>% 
  pivot_wider(
    names_from = ord_vac,
    names_sep = "_",
    values_from = c(vacuna, dia_vac, mes_vac, anio_vac, madre, 
                    dob, dov, edaddias)
  )

rm(df_f2_hijos_long_long)

#==============================================================================#
####           Construccion de los indicadores de vacunacion                ####
#==============================================================================#

# Estimacion de la edad en dias -----------------------------------------------#

df_f2_hijos_wide <- df_f2_hijos_wide %>% 
  mutate(dob = paste(anio, mes, dia)) %>%
  mutate(dov = paste(fecha_anio, fecha_mes, fecha_dia)) %>%
  mutate(dob = as_date(dob)) %>%   
  mutate(dov = as_date(dov)) %>%  
  mutate(edaddias_nin = (dob %--% dov) / days(1)) 

df_f2_hijos_wide %>%
  descr(edaddias_nin, 
        stats = c("common"),
        round.digits = 2) 

# Vacunacion BCG --------------------------------------------------------------#

# BCG
df_f2_hijos_wide %>%
  freq(vacuna_a, cumul = F, report.nas = F)

# Indicador 
df_f2_hijos_wide <- df_f2_hijos_wide %>%
  mutate(bcg = case_when(
    vacuna_a == 1 &
      (edaddias_a < 365 & !is.na(edaddias_a)) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 1,
    !is.na(vacuna_a) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_hijos_wide %>%
  freq(bcg, cumul = F, report.nas = F)

# Vacunacion Hepatitis B ------------------------------------------------------#

# Hepatitis B
df_f2_hijos_wide %>%
  freq(vacuna_b, cumul = F, report.nas = F)

# Indicador 
df_f2_hijos_wide <- df_f2_hijos_wide %>%
  mutate(hepatitis = case_when(
    vacuna_b == 1 &
      (edaddias_b < 365 & !is.na(edaddias_b)) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 1,
    !is.na(vacuna_b) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_hijos_wide %>%
  freq(hepatitis, cumul = F, report.nas = F)

# Vacunacion de rotavirus -----------------------------------------------------# 

# Rotavirus 1 
df_f2_hijos_wide %>%
  freq(vacuna_c, cumul = F, report.nas = F) 

# Rotavirus 2
df_f2_hijos_wide %>%
  freq(vacuna_d, cumul = F, report.nas = F) 

# Indicador 
df_f2_hijos_wide <- df_f2_hijos_wide %>% 
  mutate(rota_total = case_when(
    vacuna_c == 1 & vacuna_d == 1 &
      (edaddias_c < 365 & !is.na(edaddias_c)) &
      (edaddias_d < 365 & !is.na(edaddias_d)) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 1,
    !is.na(vacuna_c) & !is.na(vacuna_d) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_hijos_wide %>%
  freq(rota_total, cumul = F, report.nas = F)

# Vacunacion Pentavalente -----------------------------------------------------#

# Pentavalente 1 
df_f2_hijos_wide %>%
  freq(vacuna_e, cumul = F, report.nas = F)

# Pentavalente 2 
df_f2_hijos_wide %>%
  freq(vacuna_f, cumul = F, report.nas = F)

# Pentavalente 3 
df_f2_hijos_wide %>%
  freq(vacuna_g, cumul = F, report.nas = F)

# Indicador 
df_f2_hijos_wide <- df_f2_hijos_wide %>%
  mutate(penta_total = case_when(
    vacuna_e == 1 & vacuna_f == 1 & vacuna_g == 1 &
      (edaddias_e < 365 & !is.na(edaddias_e)) &
      (edaddias_f < 365 & !is.na(edaddias_f)) &
      (edaddias_g < 365 & !is.na(edaddias_g)) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 1,
    !is.na(vacuna_e) & !is.na(vacuna_f) & !is.na(vacuna_g) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_hijos_wide %>%
  freq(penta_total, cumul = F, report.nas = F)

# Vacunacion Antipoliomielitica -----------------------------------------------#

# Antipoliomielitica 1 
df_f2_hijos_wide %>%
  freq(vacuna_h, cumul = F, report.nas = F)

# Antipoliomielitica 2
df_f2_hijos_wide %>%
  freq(vacuna_i, cumul = F, report.nas = F)

# Antipoliomielitica 3
df_f2_hijos_wide %>%
  freq(vacuna_j, cumul = F, report.nas = F)

# Indicador 
df_f2_hijos_wide <- df_f2_hijos_wide %>%
  mutate(antip_total = case_when(
    vacuna_h == 1 & vacuna_i == 1 & vacuna_j == 1 &
      (edaddias_h < 365 & !is.na(edaddias_h)) &
      (edaddias_i < 365 & !is.na(edaddias_i)) &
      (edaddias_j < 365 & !is.na(edaddias_j)) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 1,
    !is.na(vacuna_h) & !is.na(vacuna_i) & !is.na(vacuna_j) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_hijos_wide %>%
  freq(antip_total, cumul = F, report.nas = F)

# Vacunacion neumococo --------------------------------------------------------# 

# Neumococo 1
df_f2_hijos_wide %>%
  freq(vacuna_m, cumul = F, report.nas = F) 

# Neumococo 2
df_f2_hijos_wide %>%
  freq(vacuna_n, cumul = F, report.nas = F) 

# Neumococo 3
df_f2_hijos_wide %>%
  freq(vacuna_o, cumul = F, report.nas = F) 

# Indicador 
df_f2_hijos_wide <- df_f2_hijos_wide %>%
  mutate(neumo_total = case_when(
    vacuna_m == 1 & vacuna_n == 1 & vacuna_o == 1 &
      (edaddias_m < 365 & !is.na(edaddias_m)) &
      (edaddias_n < 365 & !is.na(edaddias_n)) &
      (edaddias_o < 365 & !is.na(edaddias_o)) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 1,
    !is.na(vacuna_m) & !is.na(vacuna_n) & !is.na(vacuna_o) &
      (edaddias_nin >= 365 & !is.na(edaddias_nin)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_hijos_wide %>%
  freq(neumo_total, cumul = F, report.nas = F)

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f2_hijos_wide %>% as_survey_design(ids = c("id_upm", "id_viv"),
                                                       fpc = c("ppe", "pse"),
                                                       weights = "fexp")

options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Vacunacion BCG
survey_design %>%
  srvyr_prop(bcg)

# Vacunacion Hepatitis B 
survey_design %>%
  srvyr_prop(hepatitis)

# Vacunacion de rotavirus
survey_design %>%
  srvyr_prop(rota_total)

# Vacunacion Pentavalente
survey_design %>%
  srvyr_prop(penta_total)

# Vacunacion Antipoliomielitica
survey_design %>%
  srvyr_prop(antip_total)

# Vacunacion neumococo
survey_design %>%
  srvyr_prop(neumo_total)

