
# Titulo de la Sintaxis: 
# Caracteristicas de fecundidad de las madres

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular promedios con sus estadisticos  
srvyr_mean <- function(design, x) {
  
  design %>% 
    filter(!is.na({{ x }})) %>% 
    summarise(
      mean = survey_mean({{ x }},
                         vartype = c("se", "ci"),
                         deff = "replace",
                         na.rm = T),
      cv = survey_mean({{ x }},
                       vartype = c("cv"),
                       na.rm = T)*100,
      n = unweighted(n())) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Media = mean,
      EE    = mean_se,
      LI    = mean_low,
      LS    = mean_upp,
      CV    = cv_cv,
      Deff  = mean_deff,
      n     = n
    )
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base MEF 
df_f2_mef <- import("/BDD_ENDI_R1_f2_mef_gal.rds")
df_f2_mef <- as_tibble(df_f2_mef) 
df_f2_mef

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   
# MEF
dicc_f2_mef <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f2_mef")
dicc_f2_mef <- as_tibble(dicc_f2_mef)   
dicc_f2_mef

#==============================================================================#
####           Calculo de variables necesarias para el indicador            ####
#==============================================================================#

#------------------------------------------------------------------------------#
# Se procede a cambiar la base de mef de ancho a largo en funcion del numero 
# de hijos
#------------------------------------------------------------------------------#

# Nueva base con las variables de los hijos de las mefs
df_f2_hijos <- df_f2_mef %>% 
  select(starts_with("id"),  
         fecha_anio, fecha_mes, fecha_dia,
         f2_s1_100_1, f2_s1_100_2, f2_s1_100_3,
         fexp, ppe, pse, 
         starts_with("f2_s2_235_")) 

# Cambio de la base de ancho a largo 
df_f2_hijos_long <- df_f2_hijos %>% 
  pivot_longer(
    cols = starts_with("f2_s2_235_"),
    names_to = c(".value", "ord_hijo"),
    names_pattern = "(.*)_(.*)"
  )

df_f2_hijos_long <- df_f2_hijos_long %>% 
  rename(cod = f2_s2_235_cod,
         dia = f2_s2_235_b_dia, 
         mes = f2_s2_235_b_mes,
         anio = f2_s2_235_b_anio
  )

df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(cod = as.character(cod))

rm(df_f2_hijos, df_f2_mef)

# Creacion de variables con dos digitos  
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(cod = case_when(
    nchar(cod) == 1 ~ paste0("0", cod),
    TRUE ~ cod
  )) %>% 
  mutate(ord_hijo = case_when(
    nchar(ord_hijo) == 1 ~ paste0("0", ord_hijo),
    TRUE ~ ord_hijo
  ))

# Creacion de identificadores 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(id_hijo_ord = case_when(
    !is.na(cod) ~ paste0(id_mef, cod, ord_hijo),
    TRUE ~ NA_character_
  )) %>% 
  mutate(id_per = case_when(
    !is.na(cod) ~ paste0(id_hogar, cod),
    TRUE ~ NA_character_
  ))

# Mantengo la base de los hijos registrados 
df_f2_hijos_long_new <- df_f2_hijos_long %>% 
  filter(!is.na(id_hijo_ord))

rm(df_f2_hijos_long)

#==============================================================================#
####              Calculo de los indicadores sobre fecundidad               ####
#==============================================================================#

# Fecha de entrevista (CMC) ---------------------------------------------------#

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(fecha_dia = as.double(fecha_dia),
         fecha_anio = as.double(fecha_anio),
         fecha_mes = as.double(fecha_mes))

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(d_am_entr = fecha_dia / 30) %>% 
  mutate(d_am_entr = case_when(
    d_am_entr > 1 & !is.na(d_am_entr) ~ 1, 
    TRUE ~ d_am_entr 
  ))

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(amd_entr = (fecha_anio - 1900) * 12 + fecha_mes + d_am_entr)

df_f2_hijos_long_new %>% 
  descr(amd_entr, 
        stats = "common")

# Imputacion ------------------------------------------------------------------#

# Imputacion fecha de nacimiento 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(dia = case_when(
    dia == 99 ~ 15,
    TRUE ~ dia 
  )) %>% 
  mutate(mes = case_when(
    mes == 99 ~ 6,
    TRUE ~ mes
  )) %>% 
  mutate(anio = na_if(anio, 9999))

# Imputacion de valores no sabe / no responde 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>%
  mutate(f2_s2_235_e_dia = na_if(f2_s2_235_e_dia, 99)) %>% 
  mutate(f2_s2_235_e_mes = na_if(f2_s2_235_e_mes, 99)) %>% 
  mutate(f2_s2_235_e_anio = na_if(f2_s2_235_e_anio, 9999)) %>% 
  mutate(f2_s2_235_f_dias = na_if(f2_s2_235_f_dias, 99)) %>% 
  mutate(f2_s2_235_f_meses = na_if(f2_s2_235_f_meses, 99)) %>% 
  mutate(f2_s2_235_f_anios = na_if(f2_s2_235_f_anios, 99))

# Recuperacion ----------------------------------------------------------------#

# Recuperacion de anio de nacimiento
df_f2_hijos_long_new <- df_f2_hijos_long_new %>%
  mutate(anio_nac = f2_s2_235_e_anio - f2_s2_235_f_anios) %>% 
  mutate(anio = case_when(
    !is.na(anio_nac) & is.na(anio) ~ anio_nac,
    TRUE ~ anio 
  ))

# Recuperacion de anio de nacimiento (a partir de edad actual - vivo) 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>%
  mutate(f2_s2_235_d_anios = na_if(f2_s2_235_d_anios, 99)) 

df_f2_hijos_long_new <- df_f2_hijos_long_new %>%
  mutate(anio_nac_new = fecha_anio - f2_s2_235_d_anios) %>% 
  mutate(anio = case_when(
    !is.na(anio_nac_new) & is.na(anio) ~ anio_nac_new, 
    TRUE ~ anio 
  ))

# Fecha de nacimiento de los hijos (CMC) --------------------------------------#

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(d_am_b = dia / 30) %>% 
  mutate(d_am_b = case_when(
    d_am_b > 1 & !is.na(d_am_b) ~ 1, 
    TRUE ~ d_am_b 
  ))

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(nacim = (anio - 1900) * 12 + mes + d_am_b)

df_f2_hijos_long_new %>% 
  descr(nacim, 
        stats = "common")

# Recuperacion con datos anteriores y posteriores 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  arrange(id_mef, desc(ord_hijo))

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  group_by(id_mef) %>% 
  mutate(nacim_1 = lag(nacim)) %>% 
  mutate(nacim_2 = lead(nacim)) %>% 
  mutate(nacim_3 = (nacim_1 + nacim_2) / 2) %>% 
  ungroup()

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(nacim = case_when(
    is.na(nacim) & !is.na(nacim_3) ~ nacim_3,
    TRUE ~ nacim 
  ))

df_f2_hijos_long_new %>% 
  descr(nacim, 
        stats = "common")

df_f2_hijos_long_new <- df_f2_hijos_long_new %>%
  group_by(id_mef) %>%
  arrange(id_mef, desc(ord_hijo)) %>%
  ungroup()

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  group_by(id_mef) %>% 
  mutate(nacim_t =  nacim - lag(nacim)) %>%
  ungroup()

df_f2_hijos_long_new %>% 
  descr(nacim_t, 
        stats = "common")

df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(nacim_t = case_when(
    nacim_t < 0 & !is.na(nacim_t) ~ NA_real_,
    TRUE ~ nacim_t
  ))
# Nota: se excluyen tres casos debido a que por la imputacion de perdidos
# en fechas, las edad en meses no son consistentes entre un hijo mayor y 
# otro menor

df_f2_hijos_long_new %>% 
  descr(nacim_t, 
        stats = "common")

# Edad ninios 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(dov = paste(fecha_anio, fecha_mes, fecha_dia),
         dob = paste(anio, mes, dia),
         dov = as_date(dov),
         dob = as_date(dob),
         edaddias_nin = (dob %--% dov) / days(1),
         edadmeses_nin = trunc((dob %--% dov) / months(1)),
         edadanios_nin = trunc((dob %--% dov) / years(1))) 

df_f2_hijos_long_new %>% 
  descr(edaddias_nin, 
        stats = "common")

# Espaciamiento entre nacimientos ---------------------------------------------#

# Se quedan solo los casos de menor a 5 anios 
# Indicador
df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(nacim_t_5 = case_when(
    edaddias_nin < 1826 & !is.na(edaddias_nin) ~ nacim_t, 
    TRUE ~ NA_real_ 
  ))

df_f2_hijos_long_new %>% 
  descr(nacim_t_5, 
        stats = "common")

# Edad promedio al primer nacimiento ------------------------------------------#

# Edad madres 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(dobm = paste(f2_s1_100_3, f2_s1_100_2, f2_s1_100_1),
         dobm = as_date(dobm),
         edaddias_mad = (dobm %--% dov) / days(1),
         edadmeses_mad = trunc((dobm %--% dov) / months(1)),
         edadanios_mad = trunc((dobm %--% dov) / years(1)))

# Identificacion del hijo mayor 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  group_by(id_mef) %>% 
  mutate(hijo_mayor = case_when(
    rank(-edadanios_nin, na.last = "keep") == 1 ~ 1,
    TRUE ~ 0
  )) %>% 
  ungroup()

# Indicador 
df_f2_hijos_long_new <- df_f2_hijos_long_new %>% 
  mutate(edad_primerh = case_when(
    hijo_mayor == 1 ~ (edadanios_mad - edadanios_nin),
    TRUE ~ NA_real_))

df_f2_hijos_long_new %>% 
  descr(edad_primerh, 
        stats = "common")

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f2_hijos_long_new %>% as_survey_design(ids = c("id_upm", "id_viv"),
                                                            fpc = c("ppe", "pse"),
                                                            weights = "fexp")

options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Espaciamiento entre nacimientos
survey_design %>% 
  srvyr_mean(nacim_t_5)

# Edad promedio al primer nacimiento
survey_design %>% 
  srvyr_mean(edad_primerh)

