
# Titulo de la Sintaxis: 
# Caracteristicas de fecundidad de las madres

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular estadisticos para variables dicotomicas 
srvyr_prop <- function(design, x) {
  
  design %>% 
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace",
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base MEF 
df_f2_mef <- import("/BDD_ENDI_R1_f2_mef_gal.rds")
df_f2_mef <- as_tibble(df_f2_mef) 
df_f2_mef

# Base Salud en la Ninez 
df_f2_salud_ninez <- import("/BDD_ENDI_R1_f2_salud_ninez_gal.rds")
df_f2_salud_ninez <- as_tibble(df_f2_salud_ninez) 
df_f2_salud_ninez

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   
# MEF
dicc_f2_mef <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f2_mef")
dicc_f2_mef <- as_tibble(dicc_f2_mef)   
dicc_f2_mef

# Salud en la Ninez 
dicc_f2_sani <- import("/Diccionario_ENDI_gal.xlsx",
                       which = "f2_salud_ninez")
dicc_f2_sani <- as_tibble(dicc_f2_sani)   
dicc_f2_sani

#==============================================================================#
####           Calculo de variables necesarias para el indicador            ####
#==============================================================================#

#------------------------------------------------------------------------------#
# Se procede a cambiar la base de mef de ancho a largo en funcion del numero 
# de hijos
#------------------------------------------------------------------------------#

# Nueva base con las variables de los hijos de las mefs
df_f2_hijos <- df_f2_mef %>% 
  select(starts_with("id"), starts_with("f2_s2_235_cod_"), 
         starts_with("f2_s2_235_a_"), starts_with("f2_s2_235_b_dia_"), 
         starts_with("f2_s2_235_b_mes_"), starts_with("f2_s2_235_b_anio_")) 

# Cambio de la base de ancho a largo 
df_f2_hijos_long <- df_f2_hijos %>% 
  pivot_longer(
    cols = starts_with("f2_s2_235_"),
    names_to = c(".value", "ord_hijo"),
    names_pattern = "([A-Za-z]+)_([0-9]+)"
  ) 

df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(across(c(cod, dia, mes, anio), as.character))

df_f2_hijos_long <- df_f2_hijos_long %>% 
  rename(sexo = a)

rm(df_f2_hijos, df_f2_mef)

# Creacion de variables con dos digitos  
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(cod = case_when(
    nchar(cod) == 1 ~ paste0("0", cod),
    TRUE ~ cod
  )) %>% 
  mutate(ord_hijo = case_when(
    nchar(ord_hijo) == 1 ~ paste0("0", ord_hijo),
    TRUE ~ ord_hijo
  ))

# Creacion de identificadores 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  mutate(id_hijo_ord = case_when(
    !is.na(cod) ~ paste0(id_mef, cod, ord_hijo),
    TRUE ~ NA_character_
  ))

# Mantengo la base de los hijos registrados 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  filter(!is.na(id_hijo_ord))

# Mantengo variables a utilizar 
df_f2_hijos_long <- df_f2_hijos_long %>% 
  select(id_hijo_ord, dia, mes, anio, sexo)

#------------------------------------------------------------------------------#
# Join - Base de hijos seccion 2 y base de salud de la ninez 
#------------------------------------------------------------------------------#

# Join 
df_f2_salud_ninez_new <- df_f2_salud_ninez %>% 
  inner_join(df_f2_hijos_long, by = c("id_hijo_ord")) 

rm(df_f2_hijos_long, df_f2_salud_ninez)

#==============================================================================#
####              Calculo de los indicadores sobre fecundidad               ####
#==============================================================================#

# Embarazo deseado planeado ---------------------------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4a_403, cumul = F, report.nas = F)

# Indicador 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(emb_plan = case_when(
    f2_s4a_403 == 1 ~ 1,
    f2_s4a_403 != 1 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(emb_plan, cumul = F, report.nas = F)

# Embarazo deseado no previsto ------------------------------------------------#

# Revision 
df_f2_salud_ninez_new %>% 
  freq(f2_s4a_403, cumul = F, report.nas = F)

# Indicador 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(emb_noplan = case_when(
    f2_s4a_403 == 2 ~ 1,
    f2_s4a_403 != 2 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(emb_noplan, cumul = F, report.nas = F)

# Embarazo no previsto --------------------------------------------------------#

# Revision
df_f2_salud_ninez_new %>% 
  freq(f2_s4a_403, cumul = F, report.nas = F)

# Indicador 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(emb_noprev = case_when(
    f2_s4a_403 == 3 | f2_s4a_403 == 4 ~ 1,
    f2_s4a_403 != 3 | f2_s4a_403 != 4 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(emb_noprev, cumul = F, report.nas = F)

# Nacimientos institucionales -------------------------------------------------#

# Revision
df_f2_salud_ninez_new %>% 
  freq(f2_s4c_429_a, cumul = F, report.nas = F)

# Indicador 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(nac_inst = case_when(
    f2_s4c_429_a >= 1 & f2_s4c_429_a <= 8 ~ 1, 
    f2_s4c_429_a > 8 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(nac_inst, cumul = F, report.nas = F)

# Nacimientos atendidos por personal de salud calificado ----------------------#

# Revision
df_f2_salud_ninez_new %>% 
  freq(f2_s4c_430_a, cumul = F, report.nas = F)

# Indicador 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(nac_per_cal = case_when(
    f2_s4c_430_a >= 1 & f2_s4c_430_a <= 3 ~ 1,
    f2_s4c_430_a > 3 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(nac_per_cal, cumul = F, report.nas = F)

# Cesaria ---------------------------------------------------------------------#

# Revision
df_f2_salud_ninez_new %>% 
  freq(f2_s4c_431, cumul = F, report.nas = F)

# Indicador
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(cesaria = case_when(
    f2_s4c_431 == 2 ~ 1, 
    !is.na(f2_s4c_431) ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(cesaria, cumul = F, report.nas = F)

# Mujeres que recibieron control post parto antes de los siete dias -----------#

# Revision
df_f2_salud_ninez_new %>% 
  freq(f2_s4e_447, cumul = F, report.nas = F)

df_f2_salud_ninez_new %>% 
  descr(f2_s4e_448_a,
        stats = c("common"))

# Indicador 
df_f2_salud_ninez_new <- df_f2_salud_ninez_new %>% 
  mutate(control_post = case_when(
    f2_s4e_447 == 1 & (f2_s4e_448_a != 0 & !is.na(f2_s4e_448_a)) ~ 1,
    f2_s4e_447 == 1 & f2_s4e_448_a == 0 ~ 0,
    TRUE ~ NA_real_
  ))

df_f2_salud_ninez_new %>% 
  freq(control_post, cumul = F, report.nas = F)

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f2_salud_ninez_new %>% as_survey_design(ids = c("id_upm", "id_viv"),
                                                            fpc = c("ppe", "pse"),
                                                            weights = "fexp")

options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Embarazo deseado planeado
survey_design %>%
  srvyr_prop(emb_plan)

# Embarazo deseado no previsto 
survey_design %>%
  srvyr_prop(emb_noplan)

# Embarazo no previsto 
survey_design %>%
  srvyr_prop(emb_noprev)

# Nacimientos institucionales
survey_design %>%
  srvyr_prop(nac_inst)

# Nacimientos atendidos por personal de salud calificado
survey_design %>%
  srvyr_prop(nac_per_cal)

# Cesaria
survey_design %>%
  srvyr_prop(cesaria)

# Mujeres que recibieron control post parto antes de los siete dias
survey_design %>%
  srvyr_prop(control_post)
