
# Titulo de la Sintaxis: 
# Calidad del Agua 

# Operacion Estadistica: 
# Encuesta Nacional de Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023 

# Version: 1.0
# Software: R 4.2.0  

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analisis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para calcular estadisticos para variables dicotomicas 
srvyr_prop <- function(design, x) {
  
  design %>% 
    summarise(
      props = survey_mean({{ x }},
                          proportion = TRUE,   
                          vartype = c("se", "ci", "cv"),
                          na.rm = T) * 100, 
      deff = survey_mean({{ x }},  
                         deff = "replace",
                         na.rm = T),
      Num = sum({{ x }}, na.rm = TRUE),
      Deno = sum(!is.na({{ x }}))) %>%
    mutate(desag = "Nacional") %>%
    select(
      Desag = desag,
      Props = props, 
      EE    = props_se, 
      LI    = props_low, 
      LS    = props_upp, 
      CV    = props_cv,
      Deff  = deff_deff,
      Num   = Num, 
      Deno  = Deno
    )  
  
}

#==============================================================================#
####                          Carga de base de datos                        ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion import 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# df_f1_personas <- import("C:/ENDI/Data/f1_personas.rds")

# Sugerencias:

# Es probable que R no reconozca las rutas de archivos que comienzan con barras 
# inclinadas dobles (p. ej., “//…”) y produzcan un error. Considere mover 
# su trabajo a una unidad "con nombre" o "con letras" (p. ej., "C:" o "D:").

# Base Hogar 
df_f1_hogar <- import("/BDD_ENDI_R1_f1_hogar_gal.rds")
df_f1_hogar <- as_tibble(df_f1_hogar)
df_f1_hogar 

# Diccionario de variables 
# Cargar el archivo: Diccionario_ENDI.xlsx con la hoja ya especificada   
dicc_f1_hog <- import("/Diccionario_ENDI_gal.xlsx",
                      which = "f1_hogar") 
dicc_f1_hog <- as_tibble(dicc_f1_hog) 
dicc_f1_hog 

#==============================================================================#
####              Calculo de indicadores sobre calidad del agua             ####
#==============================================================================#

# Prueba de cloro en el punto de consumo (vaso) -------------------------------#

# Seleccion pregunta 1 entre la 1 y 6
df_f1_hogar %>%
  freq(f1_s7_8, cumul = F, report.nas = F)

# Resultado de la prueba 
df_f1_hogar %>%
  descr(f1_s7_9, 
        stats = c("common"))

# Coloracion de la muestra 
df_f1_hogar %>%
  freq(f1_s7_9_a, cumul = F, report.nas = F)

# Sin presencia de cloro en el punto de consumo (vaso) 
df_f1_hogar <- df_f1_hogar %>% 
  mutate(cloro_v_new = case_when(
    f1_s7_8 == 1 &
      ((f1_s7_9_a == 1 & (f1_s7_9 < 0.3 & !is.na(f1_s7_9))) |
         f1_s7_9_a == 2) ~ 1,
    f1_s7_8 == 1 &
      f1_s7_9_a == 1 & (f1_s7_9 >= 0.3 & !is.na(f1_s7_9)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f1_hogar %>%
  freq(cloro_v_new, cumul = F, report.nas = F)

# Prueba de cloro en la fuente ------------------------------------------------#

# Seleccion pregunta 1 entre la 1 y 6
df_f1_hogar %>%
  freq(f1_s7_12, cumul = F, report.nas = F)

# Resultado de la prueba 
df_f1_hogar %>%
  descr(f1_s7_13, 
        stats = c("common"))

# Coloracion de la muestra 
df_f1_hogar %>%
  freq(f1_s7_13_a, cumul = F, report.nas = F)

# Sin presencia de cloro en la fuente 
df_f1_hogar <- df_f1_hogar %>% 
  mutate(cloro_f_new = case_when(
    f1_s7_12 == 1 &
      ((f1_s7_13_a == 1 & (f1_s7_13 < 0.3 & !is.na(f1_s7_13))) |
         f1_s7_13_a == 2) ~ 1,
    f1_s7_12 == 1 &
      f1_s7_13_a == 1 & (f1_s7_13 >= 0.3 & !is.na(f1_s7_13)) ~ 0,
    TRUE ~ NA_real_
  ))

df_f1_hogar %>%
  freq(cloro_f_new, cumul = F, report.nas = F)

# Prueba de E.coli en el punto de consumo (vaso) ------------------------------#

# Obtencion de muestra   
df_f1_hogar %>%
  freq(f1_s7_10, cumul = F, report.nas = F)

# Total de hora de incubacion 
df_f1_hogar %>%
  descr(f1_s7_14_tothoras, 
        stats = c("common"))

# Visualizacion de resultados 
df_f1_hogar %>%
  freq(f1_s7_15, cumul = F, report.nas = F)

# Conteo de colonias 
df_f1_hogar %>%
  descr(f1_s7_16, 
        stats = c("common"))

# Validacion de la prueba 
df_f1_hogar <- df_f1_hogar %>% 
  mutate(validtest_v = case_when(
    (f1_s7_10 == 1 | f1_s7_10 == 3) & 
      (f1_s7_14_tothoras >= 24 & f1_s7_14_tothoras <= 48) & 
      f1_s7_15 == 1 ~ 1,
    (f1_s7_10 == 2 | f1_s7_10 == 4) | 
      f1_s7_15 == 2 ~ 0,
    TRUE ~ NA_real_
  )) 

df_f1_hogar %>%
  freq(validtest_v, cumul = F, report.nas = F)

# Presencia de E.coli en el punto de consumo (vaso) 
df_f1_hogar <- df_f1_hogar %>% 
  mutate(ecoli_v_new = case_when(
    validtest_v == 1 & (f1_s7_16 >= 1 & !is.na(f1_s7_16)) ~ 1, 
    validtest_v == 1 & f1_s7_16 == 0 ~ 0,
    TRUE ~ NA_real_
  ))

df_f1_hogar %>%
  freq(ecoli_v_new, cumul = F, report.nas = F)

# Prueba de E.Coli en la fuente -----------------------------------------------#

# Obtencion de muestra   
df_f1_hogar %>%
  freq(f1_s7_10, cumul = F, report.nas = F)

# Total de hora de incubacion 
df_f1_hogar %>%
  descr(f1_s7_19_tothoras, 
        stats = c("common"))

# Visualizacion de resultados 
df_f1_hogar %>%
  freq(f1_s7_20, cumul = F, report.nas = F)

# Conteo de colonias 
df_f1_hogar %>%
  descr(f1_s7_21, 
        stats = c("common"))

# Validacion de la prueba 
df_f1_hogar <- df_f1_hogar %>% 
  mutate(validtest_f = case_when(
    (f1_s7_10 == 2 | f1_s7_10 == 3) & 
      ((f1_s7_19_tothoras >= 24 & f1_s7_19_tothoras <= 48) & 
         f1_s7_20 == 1) ~ 1,
    (f1_s7_10 == 1 | f1_s7_10 == 4) |
      f1_s7_20 == 2 ~ 0,
    TRUE ~ NA_real_
  )) 

df_f1_hogar %>%
  freq(validtest_f, cumul = F, report.nas = F)

# Presencia de E.coli en la fuente 
df_f1_hogar <- df_f1_hogar %>% 
  mutate(ecoli_f_new = case_when(
    validtest_f == 1 & (f1_s7_21 >= 1 & !is.na(f1_s7_21)) ~ 1, 
    validtest_f == 1 & f1_s7_21 == 0 ~ 0,
    TRUE ~ NA_real_
  )) 

df_f1_hogar %>%
  freq(ecoli_f_new, cumul = F, report.nas = F)

#==============================================================================#
####                       Declaracion de encuesta                          ####
#==============================================================================#

survey_design <- df_f1_hogar %>% as_survey_design(ids = c("id_upm", "id_viv"),
                                                  fpc = c("ppe", "pse"),
                                                  weights = "fexp")

options(survey.lonely.psu = "adjust")

#==============================================================================#
####                         Resultados ponderados                          ####
#==============================================================================#

# Cloro
# Punto de consumo 
survey_design %>%
  srvyr_prop(cloro_v_new)

# Fuente 
survey_design %>%
  srvyr_prop(cloro_f_new)

# E.coli
# Punto de consumo 
survey_design %>%
  srvyr_prop(ecoli_v_new)

# Fuente
survey_design %>%
  srvyr_prop(ecoli_f_new)
